# Generated by Django 3.2.5 on 2021-07-22 19:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_cisco_support', '0003_auto_20210722_1917'),
    ]

    operations = [
        migrations.AddField(
            model_name='ciscosupport',
            name='is_covered',
            field=models.BooleanField(default=False),
        ),
    ]
