# Generated by Django 3.2.5 on 2021-07-22 18:57

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('dcim', '0131_consoleport_speed'),
        ('netbox_cisco_support', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='CiscoDeviceTypeSupport',
            fields=[
                ('created', models.DateField(auto_now_add=True, null=True)),
                ('last_updated', models.DateTimeField(auto_now=True, null=True)),
                ('id', models.BigAutoField(primary_key=True, serialize=False)),
                ('end_of_sale_date', models.DateField()),
                ('end_of_sw_maintenance_releases', models.DateField()),
                ('end_of_security_vul_support_date', models.DateField()),
                ('end_of_routine_failure_analysis_date', models.DateField()),
                ('end_of_service_contract_renewal', models.DateField()),
                ('last_date_of_support', models.DateField()),
                ('end_of_svc_attach_date', models.DateField()),
                ('device_type', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='dcim.devicetype')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
