# Generated by Django 3.2.5 on 2021-07-22 19:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_cisco_support', '0002_ciscodevicetypesupport'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='ciscosupport',
            name='end_of_routine_failure_analysis_date',
        ),
        migrations.RemoveField(
            model_name='ciscosupport',
            name='end_of_sale_date',
        ),
        migrations.RemoveField(
            model_name='ciscosupport',
            name='end_of_security_vul_support_date',
        ),
        migrations.RemoveField(
            model_name='ciscosupport',
            name='end_of_service_contract_renewal',
        ),
        migrations.RemoveField(
            model_name='ciscosupport',
            name='end_of_svc_attach_date',
        ),
        migrations.RemoveField(
            model_name='ciscosupport',
            name='end_of_sw_maintenance_releases',
        ),
        migrations.RemoveField(
            model_name='ciscosupport',
            name='last_date_of_support',
        ),
    ]
